@@ -36,18 +36,19 @@ Most users will want to look at TestWithFixtures and Fixture, to start with.
 # established at this point, and setup.py will use a version of next-$(revno).
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
-__version__ = (0, 3, 2, 'final', 0)
+__version__ = (0, 3, 4, 'final', 0)
 
 __all__ = [
     'EnvironmentVariableFixture',
     'Fixture',
     'FunctionFixture',
+    'MethodFixture',
     'PopenFixture',
     'TestWithFixtures',
     ]
 
 
-from fixtures.fixture import Fixture, FunctionFixture
+from fixtures.fixture import Fixture, FunctionFixture, MethodFixture
 from fixtures._fixtures import (
     EnvironmentVariableFixture,
     PopenFixture,
